==> maxdb-source-7_5_00_23.tgz: V75_00_23/MaxDB_ORG/sys/src/gg/hgg01_3.h <==
/*!******************************************************************************

  @file         hgg01_3.h

  ------------------------------------------------------------------------------

  @author       ElkeZ

  @brief        Configuration_Parameter

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (c) 2000-2004 SAP AG
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
\endif

********************************************************************************/

#ifndef HGG01_3_H
#define HGG01_3_H


/*===========================================================================*
 *     RefType: C++                                                          *
 *===========================================================================*/

/*===========================================================================*
 *     MD5: '\x8e\x60\xb5\x73\x05\x21\x73\x0c\x21\x3a\x3a\x12\x28\xda\x2d\x57'
 *===========================================================================*/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "ggg00.h"
#include "ggg04.h"
#include "ggg07.h"


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externPascal tgg04_CodeGlobals g01code;
externPascal tgg04_ControlUser g01controluser;
externPascal pasbool g01default_lru;
externPascal tgg00_KernelGlobals g01glob;
externPascal tgg00_HashPrimeList g01hashprime;
externPascal pasbool g01log_backup_to_pipe;
externPascal tsp00_Int4 g01restart_time;
externPascal tsp00_Int4 g01autosave_distance;
externPascal tgg00_LongQual g01nil_long_qual;
externPascal tgg00_SfpInitPart g01nil_sel;
externPascal tgg00_StackDesc g01nil_stack_desc;
externPascal pasbool g01nls_sort;
externPascal tsp00_KnlIdentifier g01nls_default_map;
externPascal tsp00_Int4 g01page_size;
externPascal tgg04_ServerdbIdent g01serverdb_ident;
externPascal pasbool g01sysaccount;
externPascal pasbool g01diag_moni_parse_on;
externPascal tgg04_TabIdGlobals g01tabid;
externPascal tgg00_TimeoutGlobals g01timeout;
externPascal pasbool g01unicode;
externPascal tgg00_VtraceState g01vtrace;
externPascal pasbool g01newupdstat;
externPascal tgg07_opjoin_usage g01operator_join;
externPascal pasbool gg01_operator_join_sort;
externPascal pasbool gg01_hashed_resultset;

#endif

==> maxdb-source-7_5_00_34.tgz: V75_00_34/MaxDB_ORG/sys/src/gg/hgg01_3.h <==
/*!******************************************************************************

  @file         hgg01_3.h

  ------------------------------------------------------------------------------

  @author       <unknown>

  @brief        <unknown topic>

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
\endif

********************************************************************************/

#ifndef HGG01_3_H
#define HGG01_3_H


/*===========================================================================*
 *     RefType: C++                                                          *
 *===========================================================================*/

/*===========================================================================*
 *     MD5: '\xee\xa5\xf6\x03\xd8\x49\x04\x84\xe0\x7e\xce\xb7\x72\xe2\x9b\xe6'
 *===========================================================================*/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "ggg00.h"
#include "ggg04.h"
#include "ggg07.h"


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externPascal tgg04_CodeGlobals g01code;
externPascal tgg04_ControlUser g01controluser;
externPascal pasbool g01default_lru;
externPascal tgg00_KernelGlobals g01glob;
externPascal tgg00_HashPrimeList g01hashprime;
externPascal pasbool g01log_backup_to_pipe;
externPascal tsp00_Int4 g01restart_time;
externPascal tsp00_Int4 g01autosave_distance;
externPascal tgg00_LongQual g01nil_long_qual;
externPascal tgg00_SfpInitPart g01nil_sel;
externPascal tgg00_StackDesc g01nil_stack_desc;
externPascal pasbool g01nls_sort;
externPascal tsp00_KnlIdentifier g01nls_default_map;
externPascal tsp00_Int4 g01page_size;
externPascal tgg04_ServerdbIdent g01serverdb_ident;
externPascal pasbool g01sysaccount;
externPascal pasbool g01diag_moni_parse_on;
externPascal tgg04_TabIdGlobals g01tabid;
externPascal tgg00_TimeoutGlobals g01timeout;
externPascal pasbool g01unicode;
externPascal tgg00_VtraceState g01vtrace;
externPascal tsp00_Int4 g01updstatalgo;
externPascal tgg07_opjoin_usage g01operator_join;
externPascal pasbool gg01_operator_join_costfunc;
externPascal pasbool gg01_operator_join_sort;
externPascal pasbool gg01_hashed_resultset;
externPascal tsp00_Int4 gg01optimize_parallel_server;
externPascal pasbool gg01_optim_inv_only;
externPascal pasbool gg01_diag_frows_optim;
externPascal pasbool gg01_checktablewidth;

#endif
